#
# spec file for package python-MDP
#
# Copyright (c) 2017 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define oldpython python
%bcond_with     test
Name:           python-MDP
Version:        3.5
Release:        4.1
License:        BSD-3-Clause
Summary:        A Python library for building complex data processing software
Url:            http://mdp-toolkit.sourceforge.net/
Source:         https://files.pythonhosted.org/packages/source/M/MDP/MDP-%{version}.tar.gz
Group:          Development/Languages/Python
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module future}
BuildRequires:  %{python_module joblib >= 0.4.3}
BuildRequires:  %{python_module numpy-devel >= 1.1}
BuildRequires:  %{python_module scipy >= 0.5.2}
BuildRequires:  %{python_module scikit-learn >= 0.6}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if %{with test}
BuildRequires:  %{python_module pytest}
%endif
Requires:       python-future
Requires:       python-numpy >= 1.1
Recommends:     python-joblib >= 0.4.3
Recommends:     python-scipy >= 0.5.2
Recommends:     python-scikit-learn >= 0.6
%ifpython2
Obsoletes:      %{oldpython}-mdp < %{version}
Provides:       %{oldpython}-mdp = %{version}
%endif
%ifpython3
Obsoletes:      python3-mdp < %{version}
Provides:       python3-mdp = %{version}
%endif
BuildArch:      noarch

%python_subpackages

%description
The Modular toolkit for Data Processing (MDP) package is a library
of widely used data processing algorithms, and the possibility to
combine them together to form pipelines for building more complex
data processing software.

MDP has been designed to be used as-is and as a framework for
scientific data processing development.

%prep
%setup -q -n MDP-%{version}

%build
%python_build

%install
%python_install
%{python_expand %fdupes %{buildroot}%{$python_sitelib}
$python -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/mdp/test/
$python -O -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/mdp/test/
%fdupes %{buildroot}%{$python_sitelib}/mdp/test/
}

%if %{with test}
%check
%python_exec -B -m pytest mdp
%endif

%files %{python_files}
%defattr(-,root,root,-)
%doc CHANGES COPYRIGHT README TODO
%{python_sitelib}/bimdp/
%{python_sitelib}/mdp/
%{python_sitelib}/MDP-%{version}-py*.egg-info

%changelog
* Wed Aug 23 2017 toddrme2178@gmail.com
- Rename to python-MDP to match openSUSE python package naming
  guidelines.
- Implement single-spec version
- Update to version 3.5
  * fix use of str in biflow indexing
  * remove obsolete scripts
  * Add wrapper function for exec Old Python versions don't allow exec
    statement in nested functions
- Update to version 3.4
  * Make use of setuptools instead of distutils While we resisted as
    long as possible, it is now time to move to use setuptools
    officially. This makes MDP installable properly with pip. This
    means that our dependencies are now explicitly declared
    (numpy and future). Optional dependencies are also declared and can
    be installed using the "pip -e MDP[optionaldep]" command, where
    optionaldep can be scipy, or scikit-learn or ... Moreover,
    automatic testing using "python setup.py test" now works, which
    makes MDP finally conform this non-written standard and makes it
    easy to run tests for clueless people.
  * add new modules in sklearn wrappers
  * Remove self-contained py.test script... The use of the
    self-contained script for py.test has been deprecated for a while
    and has stop working. We now require py.test to be installed to run
    the tests.
  * remove obsolete stuff related to py3 conversion with lib2to3
  * Disable support for shogun > 1 it would be too much work to enable
    support for newer shogun versions...
  * disable failing monkeypatching test for pp...
    .. the pp monkeypatching trick is not needed anymore anyways...
  * futurize stage 2: code is now py2&3 compatible
  * futurize stage1: code should still be python2.6 compatible
  * compatibility fixes for numpy 1.11..,
    ...numpy now refuses to index arrays using floats and default dtype
    for zeros and ones has been changed from integers to floats.
  * several new sklearn autogenerated nodes need additional arguments
    to be tested
  * FIX: fixed broken inclusion of CSS data
  * FIX: hacky fix for the unicode issue in bimdp autogen (fix for Bug
    [#11])
  * NEW: added extension setup and teardown function decorator
  * DOC: some small updates and fixes in docstrings and comments
  * FIX: cStringIO does not support Unicode
    `autogen` was breaking in nodes with Unicode characters in their
    docstring. We traced this down to cStringIO, which unlike StringIO
    does not support unicode.
  * FIX: wrap sklearn algs in modules ending with "_" For historical
    reasons we were not wrapping sklearn algs in modules with names
    ending with "_". This restriction prevented us from wrapping algs
    that we could have wrapped. We lift it now, since it does not seem
    to have any bad side effects anymore. A proper validation would be
    to really test that we can run the algs.
  * NEW: update local copy of py.test to version 2.3.4
  * FIX: made code and documentation consistent regarding the parameter
    k in invert_exp_funcs2
  * DOC: indicated what expansion failed in the tests of
    GeneralExpansionNode
  * DOC: added an example to GeneralExpansionNode and made the
    documentation more explicit
  * FIX: make pip work without explicit URL. now we point directly to
    the tar archive in the download_url field of the setup.py file.
  * DOC: moved coarse_limit description under FastICA and removed
    signature (present elsewhere)
  * ENH: FastICA - test having some coarse_limit
  * ENH: FastICA -- primary_limit -> coarse_limit + default to None
    Introduced to make things a bit clearer since there is already
    "fine tuning" stage where optimization switches to used_g upon
    reaching the limit. Calling the limit "coarse" instead of
    "primary/secondary" would help to preserve original messages/logic
    thus not confusing existing users, while still allowing to kick in
    gFine before reaching the limit
  * ENH: 2 stage optimization for FastICA found in current AFNI
  * DOC: bumped version number after release ;)
  * OTH: updated CHANGES and COPYRIGHT
  * NEW: add support for newest sklearn algorithms
* Sun Dec  8 2013 p.drouand@gmail.com
- Update to version 3.3
  + fix error in automatic testing for MultinomialNB.
  + make sklearn nodes automatic testing more robust The previous
    solution was actually ignoring the special definitions in NODES.
  + disable pp support if server can not start Being able to
    import pp is not enough to be sure that pp works. For example in a
    low memory situation, the following can happen:
    >>> import pp
    >>> server = pp.Server()
    [...] OSError: [Errno 12] Cannot allocate memory
    This fix just disables pp support if the server can not be
    started.
  + Fix wrapping of sklearn 0.11 classifiers
  + make test_SFA2Node even more robust
  + make FastICANode test more robust
  + make test_SFA2Node more robust
  + fix pp_tests when run multiple times. pp tests were failing
    when run twice in a row. hugly work-around, but it seems to
    work...
  + fixed broken test_reload. test_reload was failing when called
    twice in a row.
  + fix random seed tests. The tests were failing when called
    twice in a row:
    >>> import mdp
    >>> mdp.test()
    >>> mdp.test() the first call was working, the second one was
    giving failures.
  + added tests for learning of bias parameters
  + replace third remaing test for pp_monkeypatch_dirname
    Hopefully this will fix test suite failures.
  + Decrease the noise level in the DiscreteHopfieldClassifier.
  + honor MDP_DISABLE_SHOGUN env variable
  + fix left-over directories from testing pp. I do not know why,
    but this simple change fixes the leftover directories problem when
    testig with python-pp and pp monkey-patching. It should have
    worked even as it was before, but apparently some race condition
    happens.
  + fix determinant of random rotation matrix determinant sign
    was wrong if dimensions of rotation matrix were odd. Actual Fix.
  + remove duplicated and overly verbose code
  + remove FastICA stabilization from tests
  + remove unused parameter stabilization in FastICA.
  + added new sklearn algorithms wrapping We now wrap 93 sklearn
    algorithms!
  + fix another imcompatibility with sklearn 0.10 Although
    EllipticEnvelop is derived from sklearn.base.ClassifierMixin, it
    is not a classifier. It is actually a "predictor". Added a check
    in the sklearn wrappers.
  + fix sklearn wrappers for version 0.10 New sklearn version
    introduces classifiers and predictors mixin classes that do not
    have a 'fit' method. Typical error:
    AttributeError: type object 'OutlierDetectionMixin' has no
    attribute 'fit'
    Just added a check that the method is really present before
    wrapping.
  + fix failing test for no eigenvalues left problem Check that
    PCANode now raises the right exception.
  + add useful exception in case of no eigenvalues left. Check
    for the condition explained in
    b0810d72ce11925e1db6204c3a20bdfc77741a82 and raise a nicely
    formatted exception:
    Traceback:
    [...] File ".../mdp/nodes/pca_nodes.py", line 223, in
    _stop_training
    ' var_abs=%%e!'%%self.var_abs) NodeException: No eigenvalues
    larger than var_abs=1.000000e-15!
  + OTH: added failing test for no eigenvalues left problem. When
    PCANode is set to use SVD and automatic dimensionality reduction
    it may happen that after removing directions corresponding to
    eigenvalues smaller than var_abs (1e-12 default), nothing is left.
    This happens for example if the data is a matrix of (almost)
    zeros. The error looks like this: Traceback (most recent call
    last):
    [...] File ".../mdp/nodes/pca_nodes.py", line 220, in
    _stop_training
    d = d[ d / d.max() > self.var_rel ] ValueError: zero-size array
    to ufunc.reduce without identity
  + old joblib breaks imports from sklearn.decomposition
    >>> import sklearn.decomposition Traceback (most recent call
    last):
    File "<stdin>", line 1, in <module>
    File
    "/usr/lib/pymodules/python2.6/sklearn/decomposition/__init__.py",
    line 8, in <module>
    from .sparse_pca import SparsePCA, MiniBatchSparsePCA
    File
    "/usr/lib/pymodules/python2.6/sklearn/decomposition/sparse_pca.py",
    line 10, in <module>
    from .dict_learning import dict_learning, dict_learning_online
    File
    "/usr/lib/pymodules/python2.6/sklearn/decomposition/dict_learning.py",
    line 17, in <module>
    from ..externals.joblib import Parallel, delayed, cpu_count
    ImportError: cannot import name cpu_count
    >>> joblib.__version__
    '0.4.3'
  + py3k compatibility for reload reload() is moved to
    imp.reload().
    It also seems that Python 3 behaves slightly differently wrt.
    reloads. For some reason, mdp.configuration is not imported
    properly on reload. Let's just not remove the name from the
    namespace, as this is the easiest fix.
  + added a failing test for reload MDP does not work with
    reload. See https://github.com/mdp-toolkit/mdp-toolkit/issues/1
    for details.
  + Removed the leftover _global_message_emitter attribute
  + fix wrong sorting of eigenvectors in degenerate case for SVD.
  + added failing test for wrong sorting of SVDs
  + updated sklearn wrappers to silence warnings for version >= 0.9
- Remove fix-sklearn-{0.9/0.10-1/0.10-2/0.11}.patch; fixed on
  upstream release
- Remove useless CFLAGS definition
- Remove depreciated python(abi) >= %%{py_ver} requirement
- Fix Url; pypi redirect on most recent version page
* Thu Sep  6 2012 toddrme2178@gmail.com
- Backport python-scikit-learn compatibility fixes
* Wed Sep  5 2012 toddrme2178@gmail.com
- Initial version
